tuplettools.make_tuplet_from_nonreduced_ratio_and_nonreduced_fraction
=====================================================================

.. autofunction:: abjad.tools.tuplettools.make_tuplet_from_nonreduced_ratio_and_nonreduced_fraction.make_tuplet_from_nonreduced_ratio_and_nonreduced_fraction
   :noindex:
